@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-#  Copyright (C) 2004-2016 by Shyouzou Sugitani <shy@users.osdn.me>
+#  Copyright (C) 2004-2017 by Shyouzou Sugitani <shy@users.osdn.me>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -32,41 +32,24 @@ module Kinoko
 
     def initialize(accelgroup)
       @parent = nil
-      ui_info = <<-EOS
-        <ui>
-          <popup name='popup'>
-            <menuitem action='Settings'/>
-            <menu action='Skin'>
-            </menu>
-            <separator/>
-            <menuitem action='Exit'/>
-          </popup>
-        </ui>
-      EOS
-      @__menu_list = {
-        'settings' => [['Settings', nil, _('Settings...(_O)'), nil,
-                        '', lambda {|a, b| @parent.handle_request('NOTIFY', 'edit_preferences')}],
-                       '/ui/popup/Settings'],
-        'skin' => [['Skin', nil, _('Skin(_K)'), nil],
-                   nil, '/ui/popup/Skin'],
-        'exit' => [['Exit', nil, _('Exit(_Q)'), nil,
-                    '', lambda {|a, b| @parent.handle_request('NOTIFY', 'close')}],
-                   '/ui/popup/Exit'],
-      }
-      actions = Gtk::ActionGroup.new('Actions')
-      entry = []
-      for value in @__menu_list.values()
-        entry << value[0]
+      @__menu_list = {}
+      @__popup_menu = Gtk::Menu.new
+      item = Gtk::MenuItem.new(:label => _('Settings...(_O)'), :use_underline => true)
+      item.signal_connect('activate') do |a, b|
+        @parent.handle_request('NOTIFY', 'edit_preferences')
       end
-      actions.add_actions(entry)
-      ui_manager = Gtk::UIManager.new()
-      ui_manager.insert_action_group(actions, 0)
-      ui_manager.add_ui(ui_info)
-      @__popup_menu = ui_manager.get_widget('/ui/popup')
-      for key in @__menu_list.keys
-        path = @__menu_list[key][-1]
-        @__menu_list[key][1] = ui_manager.get_widget(path)
+      @__popup_menu.add(item)
+      @__menu_list['settings'] = item
+      item = Gtk::MenuItem.new(:label => _('Skin(_K)'), :use_underline => true)
+      @__popup_menu.add(item)
+      @__menu_list['skin'] = item
+      item = Gtk::MenuItem.new(:label => _('Exit(_Q)'), :use_underline => true)
+      item.signal_connect('activate') do |a, b|
+        @parent.handle_request('NOTIFY', 'close')
       end
+      @__popup_menu.add(item)
+      @__menu_list['exit'] = item
+      @__popup_menu.show_all
     end
 
     def set_responsible(parent)
@@ -81,10 +64,10 @@ module Kinoko
 
     def set_skin_menu(list)
       key = 'skin'
-      if not list.empty?
+      unless list.empty?
         menu = Gtk::Menu.new
         for skin in list
-          item = Gtk::MenuItem.new(skin['title'])
+          item = Gtk::MenuItem.new(:label => skin['title'])
           item.signal_connect('activate', skin) do |a, k|
             @parent.handle_request('NOTIFY', 'select_skin', k)
             next true
@@ -92,11 +75,11 @@ module Kinoko
           menu.add(item)
           item.show()
         end
-        @__menu_list[key][1].set_submenu(menu)
+        @__menu_list[key].set_submenu(menu)
         menu.show()
-        @__menu_list[key][1].show()
+        @__menu_list[key].show()
       else
-        @__menu_list[key][1].hide()
+        @__menu_list[key].hide()
       end
     end
   end
@@ -120,42 +103,33 @@ module Kinoko
     def finalize()
       @__running = false
       @target.detach_observer(self)
-      if @skin != nil
-        @skin.destroy()
-      end
+      @skin.destroy() unless @skin.nil?
     end
 
     def observer_update(event, args)
-      if @skin == nil
-        return
-      end
-      if ['set position', 'set surface'].include?(event)
+      return if @skin.nil?
+      case event
+      when 'set position', 'set surface'
         @skin.set_position()
         @skin.show()
-      elsif event == 'set scale'
+      when 'set scale'
         scale = @target.get_surface_scale()
         @skin.set_scale(scale)
-      elsif event == 'hide'
-        side = args
-        if side == 0 # sakura side
-          @skin.hide()
-        end
-      elsif event == 'iconified'
+      when 'hide'
+        side = args[0]
+        @skin.hide() if side.zero? # sakura side
+      when 'iconified'
         @skin.hide()
-      elsif event == 'deiconified'
+      when 'deiconified'
         @skin.show()
-      elsif event == 'finalize'
+      when 'finalize'
         finalize()
-      elsif event == 'move surface'
+      when 'move surface'
         side, xoffset, yoffset = args
-        if side == 0 # sakura side
-          @skin.set_position(:xoffset => xoffset, :yoffset => yoffset)
-        end
-      elsif event == 'raise'
-        side = args
-        if side == 0 # sakura side
-          @skin.set_position()
-        end
+        @skin.set_position(:xoffset => xoffset, :yoffset => yoffset) if side.zero? # sakura side
+      when 'raise'
+        side = args[0]
+        @skin.set_position() if side.zero? # sakura side
       else
         Logging::Logging.debug('OBSERVER(kinoko): ignore - ' + event)
       end
@@ -183,9 +157,7 @@ module Kinoko
           result = nil
         end
       end
-      if event_type == 'GET'
-        return result
-      end
+      return result if event_type == 'GET'
     end
 
     def load(data, target)
@@ -194,22 +166,15 @@ module Kinoko
       @target.attach_observer(self)
       @accelgroup = Gtk::AccelGroup.new()
       load_skin()
-      if @skin == nil
-        return 0
-      else
-        send_event('OnKinokoObjectCreate')
-      end
+      return 0 if @skin.nil?
+      send_event('OnKinokoObjectCreate')
       @__running = true
       GLib::Timeout.add(10) { do_idle_tasks } # 10[ms]
       return 1
     end
 
     def do_idle_tasks()
-      if @__running
-        return true
-      else
-        return false
-      end
+      @__running
     end
 
     def close()
@@ -218,13 +183,11 @@ module Kinoko
     end
 
     def send_event(event)
-      if not ['OnKinokoObjectCreate', 'OnKinokoObjectDestroy',
-              'OnKinokoObjectChanging', 'OnKinokoObjectChanged',
-              'OnKinokoObjectInstalled'].include?(event)
-        ## 'OnBatteryLow', 'OnBatteryCritical',
-        ## 'OnSysResourceLow', 'OnSysResourceCritical'
-        return
-      end
+      return unless ['OnKinokoObjectCreate', 'OnKinokoObjectDestroy',
+                     'OnKinokoObjectChanging', 'OnKinokoObjectChanged',
+                     'OnKinokoObjectInstalled'].include?(event)
+      ## 'OnBatteryLow', 'OnBatteryCritical',
+      ## 'OnSysResourceLow', 'OnSysResourceCritical'
       args = [@data['title'],
               @data['ghost'],
               @data['category']]
@@ -232,7 +195,7 @@ module Kinoko
     end
 
     def get_skin_list()
-      return @skin_list
+      @skin_list
     end
 
     def select_skin(args)
@@ -240,11 +203,8 @@ module Kinoko
       @skin.destroy()
       @data = args
       load_skin()
-      if @skin == nil
-        return 0
-      else
-        send_event('OnKinokoObjectChanged')
-      end
+      return 0 if @skin.nil?
+      send_event('OnKinokoObjectChanged')
       return 1
     end
   end
@@ -260,7 +220,7 @@ module Kinoko
     end
 
     def get_seriko
-      return @seriko
+      @seriko
     end
 
     def set_responsible(parent)
@@ -280,9 +240,7 @@ module Kinoko
           result = @parent.handle_request(event_type, event, *arglist)
         end
       end
-      if event_type == 'GET'
-        return result
-      end
+      return result if event_type == 'GET'
     end
 
     def load(data, scale)
@@ -298,7 +256,7 @@ module Kinoko
         next true
       end
       @window.add_accel_group(@accelgroup)
-      if @data['animation'] != nil
+      unless @data['animation'].nil?
         path = File.join(@data['dir'], @data['animation'])
         actors = {'' => Seriko.get_actors(NConfig.create_from_file(path))}
       else
@@ -364,29 +322,22 @@ module Kinoko
     end
 
     def get_surface_id
-      return @surface_id
+      @surface_id
     end
 
     def get_preference(name) # dummy
-      if name == 'animation_quality'
-        return 1.0
-      else
-        return nil
-      end
+      return 1.0 if name == 'animation_quality'
+      return nil
     end
 
     def show()
-      if not @__shown
-        @window.show_all()
-        @__shown = true
-      end
+      @window.show_all() unless @__shown
+      @__shown = true
     end
 
     def hide()
-      if @__shown
-        @window.hide_all()
-        @__shown = false
-      end
+      @window.hide_all() if @__shown
+      @__shown = false
     end
 
     def append_actor(frame, actor)
@@ -431,7 +382,7 @@ module Kinoko
     end
 
     def create_image_surface(surface_id)
-      if surface_id != nil and surface_id != ''
+      unless surface_id.nil? or surface_id.empty?
         surface = get_image_surface(surface_id)
       else
         surface = Pix.create_surface_from_file(@path)
@@ -441,7 +392,7 @@ module Kinoko
 
     def update_frame_buffer()
       new_surface = create_image_surface(@seriko.get_base_id)
-      rasie "assert" unless new_surface != nil
+      raise "assert" if new_surface.nil?
       # draw overlays
       for surface_id, x, y, method in @seriko.iter_overlays()
         begin
