@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-#  Copyright (C) 2003-2016 by Shyouzou Sugitani <shy@users.osdn.me>
+#  Copyright (C) 2003-2017 by Shyouzou Sugitani <shy@users.osdn.me>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -71,10 +71,8 @@ module Pix
       end
       @supports_alpha = composited?
       fail "assert" unless not visual.nil?
-      left, top = 0, 0 # XXX
-      width = (screen.width - left)
-      height = (screen.height - top)
-      @workarea = [left, top, width, height]
+      workarea = screen.display.primary_monitor.workarea # XXX
+      @workarea = [workarea.x, workarea.y, workarea.width, workarea.height]
     end
   end
 
@@ -112,8 +110,8 @@ module Pix
     def move(x, y)
       left, top, scrn_w, scrn_h = @workarea
       w, h = @darea.size_request() # XXX
-      new_x = [[left, x].max, scrn_w - w].min
-      new_y = [[top, y].max, scrn_h - h].min
+      new_x = [[left, x].max, left + scrn_w - w].min
+      new_y = [[top, y].max, top + scrn_h - h].min
       base_move(new_x, new_y)
       @__position = [new_x, new_y]
       @__surface_position = [x, y]
@@ -153,7 +151,9 @@ module Pix
 
     def set_shape(cr)
       region = Pix.surface_to_region(cr.target.map_to_image)
-      if @supports_alpha
+      if RbConfig::CONFIG['host_os'] =~ /mswin|mingw|cygwin/
+        shape_combine_region(nil)
+      elsif @supports_alpha
         input_shape_combine_region(nil)
         input_shape_combine_region(region)
       else
@@ -328,7 +328,7 @@ module Pix
     return surface
   end
 
-  def self.create_pixbuf_from_file(path, is_pnr: true, use_pna: false)
+  def self.create_pixbuf_from_file(path, is_pnr: false, use_pna: false)
     head = File.dirname(path)
     basename = File.basename(path, '.*')
     pixbuf =
@@ -340,6 +340,9 @@ module Pix
       else
         pixbuf_new_from_file(path)
       end
+    # Currently cannot get a pointer to the actual pixels with
+    # the pixels method. Temporary use the read_pixel_bytes method and
+    # create another Pixbuf.
     if is_pnr
       pixels = pixbuf.read_pixel_bytes
       unless pixbuf.has_alpha?
